@@ -14,9 +14,13 @@ __all__ = ['encode','decode','jdtype','jsonfilter']
 import numpy as np
 import copy
 import zlib
-import lzma
 import base64
 
+try:
+    import lzma
+except ImportError:
+    from backports import lzma
+
 ##====================================================================================
 ## global variables
 ##====================================================================================
@@ -28,7 +32,8 @@ complex-valued data are reflected in the doubled data size
 jdtype={'float32':'single','float64':'double','float_':'double',
 'bool':'uint8','byte':'int8','short':'int16','ubyte':'uint8',
 'ushort':'uint16','int_':'int32','uint':'uint32','complex_':'double','complex128':'double',
-'longlong':'int64','ulonglong':'uint64','csingle':'single','cdouble':'double'};
+'complex64':'single','longlong':'int64','ulonglong':'uint64',
+'csingle':'single','cdouble':'double'};
 
 _zipper=['zlib','gzip','lzma'];
 
@@ -169,6 +174,8 @@ def jsonfilter(obj):
             return obj.tolist()
         else:
             return obj.item()
+    elif isinstance(obj, (bytes, bytearray)):
+        return obj.decode("utf-8")
     elif isinstance(obj, float):
         if(np.isnan(obj)):
             return '_NaN_';
@@ -177,7 +184,7 @@ def jsonfilter(obj):
 
 def encodedict(d0, opt={}):
     d=dict(d0);
-    for k, v in d.items():
+    for k, v in d0.items():
         newkey=encode(k,opt)
         d[newkey]=encode(v,opt);
         if(k!=newkey):
